Package

Struct Package 

pub struct Package(/* private fields */);
A package in the APT package manager.

Implementations

Source

impl Package

pub fn new(paragraph: Paragraph) -> Self

Create a new package.

pub fn parse(text: &str) -> Parse<Package>

Parse package text, returning a Parse result

Note: This expects a single paragraph, not a full deb822 document

pub fn name(&self) -> Option<String>

Get the name of the package.

pub fn set_name(&mut self, name: &str)

Set the name of the package.

pub fn version(&self) -> Option<Version>

Get the version of the package.

pub fn set_version(&mut self, version: Version)

Set the version of the package.

pub fn installed_size(&self) -> Option<usize>

Get the installed size of the package in bytes.

pub fn set_installed_size(&mut self, size: usize)

Set the installed size of the package in bytes.

pub fn maintainer(&self) -> Option<String>

Get the maintainer of the package.

pub fn set_maintainer(&mut self, maintainer: &str)

Set the maintainer of the package.

pub fn architecture(&self) -> Option<String>

Get the architecture of the package.

pub fn set_architecture(&mut self, arch: &str)

Set the architecture of the package.

pub fn depends(&self) -> Option<Relations>

Get the packages that this package depends on.

pub fn set_depends(&mut self, relations: Relations)

Set the packages that this package depends on.

pub fn recommends(&self) -> Option<Relations>

Get the packages that this package suggests.

pub fn set_recommends(&mut self, relations: Relations)

Set the packages that this package recommends.

pub fn suggests(&self) -> Option<Relations>

Get the packages that this package suggests.

pub fn set_suggests(&mut self, relations: Relations)

Set the packages that this package suggests.

pub fn enhances(&self) -> Option<Relations>

Get the packages that this package enhances.

pub fn set_enhances(&mut self, relations: Relations)

Set the packages that this package enhances.

pub fn pre_depends(&self) -> Option<Relations>

Get the relations that this package pre-depends on.

pub fn set_pre_depends(&mut self, relations: Relations)

Set the relations that this package pre-depends on.

pub fn breaks(&self) -> Option<Relations>

Get the relations that this package breaks.

pub fn set_breaks(&mut self, relations: Relations)

Set the relations that this package breaks.

pub fn conflicts(&self) -> Option<Relations>

Get the relations that this package conflicts with.

pub fn set_conflicts(&mut self, relations: Relations)

Set the relations that this package conflicts with.

pub fn replaces(&self) -> Option<Relations>

Get the relations that this package replaces.

pub fn set_replaces(&mut self, relations: Relations)

Set the relations that this package replaces.

pub fn provides(&self) -> Option<Relations>

Get the relations that this package provides.

pub fn set_provides(&mut self, relations: Relations)

Set the relations that the package provides.

pub fn section(&self) -> Option<String>

Get the section of the package.

pub fn set_section(&mut self, section: &str)

Set the section of the package.

pub fn priority(&self) -> Option<Priority>

Get the priority of the package.

pub fn set_priority(&mut self, priority: Priority)

Set the priority of the package.

pub fn description(&self) -> Option<String>

Get the description of the package.

pub fn set_description(&mut self, description: &str)

Set the description of the package.

pub fn homepage(&self) -> Option<Url>

Get the upstream homepage of the package.

pub fn set_homepage(&mut self, url: &Url)

Set the upstream homepage of the package.

pub fn source(&self) -> Option<String>

Get the source of the package.

pub fn set_source(&mut self, source: &str)

Set the source of the package.

pub fn description_md5(&self) -> Option<String>

Get the MD5 checksum of the description.

pub fn set_description_md5(&mut self, md5: &str)

Set the MD5 checksum of the description.

pub fn tags(&self, tag: &str) -> Option<Vec<String>>

Get the tags of the package.

pub fn set_tags(&mut self, tag: &str, tags: Vec<String>)

Set the tags of the package.

pub fn filename(&self) -> Option<String>

Get the filename of the package.

pub fn set_filename(&mut self, filename: &str)

Set the filename of the package.

pub fn size(&self) -> Option<usize>

Get the size of the package.

pub fn set_size(&mut self, size: usize)

Set the size of the package.

pub fn md5sum(&self) -> Option<String>

Get the MD5 checksum.

pub fn set_md5sum(&mut self, md5sum: &str)

Set the MD5 checksum.

pub fn sha256(&self) -> Option<String>

Get the SHA256 checksum.

pub fn set_sha256(&mut self, sha256: &str)

Set the SHA256 checksum.

pub fn multi_arch(&self) -> Option<MultiArch>

Get the multi-arch field.

pub fn set_multi_arch(&mut self, arch: MultiArch)

Set the multi-arch field.