Changes

Struct Changes 

pub struct Changes(/* private fields */);
Changes file

Implementations

Source

impl Changes

pub fn parse(text: &str) -> Parse<Changes>

Parse changes text, returning a Parse result

Note: This expects a single paragraph, not a full deb822 document

pub fn format(&self) -> Option<String>

Returns the format of the Changes file.

pub fn set_format(&mut self, value: &str)

Set the format of the Changes file.

pub fn source(&self) -> Option<String>

Returns the name of the source package.

pub fn binary(&self) -> Option<Vec<String>>

Returns the list of binary packages generated by the source package.

pub fn architecture(&self) -> Option<Vec<String>>

Returns the architecture the source package is intended for.

pub fn version(&self) -> Option<Version>

Returns the version of the source package.

pub fn distribution(&self) -> Option<String>

Returns the distribution the source package is intended for.

pub fn urgency(&self) -> Option<Urgency>

Returns the urgency of the source package.

pub fn maintainer(&self) -> Option<String>

Returns the name and email address of the person who maintains the package.

pub fn changed_by(&self) -> Option<String>

Returns the name and email address of the person who uploaded the package.

pub fn description(&self) -> Option<String>

Returns the description of the source package.

pub fn checksums_sha1(&self) -> Option<Vec<Sha1Checksum>>

Returns the SHA-1 checksums of the files in the source package.

pub fn checksums_sha256(&self) -> Option<Vec<Sha256Checksum>>

Returns the SHA-256 checksums of the files in the source package.

pub fn files(&self) -> Option<Vec<File>>

Returns the list of files in the source package.

pub fn get_pool_path(&self) -> Option<String>

Returns the path to the pool directory for the source package.

pub fn new() -> Self

Create a new Changes file.

pub fn from_file<P: AsRef<Path>>(path: P) -> Result<Self, ParseError>

Read a Changes file from a file.

pub fn from_file_relaxed<P: AsRef<Path>>( path: P, ) -> Result<(Self, Vec<String>), Error>

Read a Changes file from a file, allowing syntax errors.

pub fn read<R: Read>(r: R) -> Result<Self, ParseError>

Read a Changes file from a reader.

pub fn read_relaxed<R: Read>(r: R) -> Result<(Self, Vec<String>), Error>

Read a Changes file from a reader, allowing syntax errors.