Identity

Struct Identity 

pub struct Identity {
    pub name: String,
    pub email: String,
    pub email_range: TextRange,
}
A parsed Name <email> identity from a Maintainer: or Uploaders: field, with the byte range of the email address inside the source document.

Fields

name: String

The name part (may be empty for bare-email entries).

email: String

The email address (with no surrounding angle brackets).

email_range: TextRange

The text range of the email inside the source document.