pub struct Source {Show 31 fields
pub directory: String,
pub description: Option<String>,
pub version: Version,
pub package: String,
pub binaries: Option<Vec<String>>,
pub maintainer: Option<String>,
pub build_depends: Option<Relations>,
pub build_depends_indep: Option<Relations>,
pub build_depends_arch: Option<Relations>,
pub build_conflicts: Option<Relations>,
pub build_conflicts_indep: Option<Relations>,
pub build_conflicts_arch: Option<Relations>,
pub standards_version: Option<String>,
pub homepage: Option<String>,
pub autobuild: Option<bool>,
pub testsuite: Option<String>,
pub testsuite_triggers: Option<Vec<String>>,
pub vcs_browser: Option<String>,
pub vcs_git: Option<String>,
pub vcs_bzr: Option<String>,
pub vcs_hg: Option<String>,
pub vcs_svn: Option<String>,
pub vcs_darcs: Option<String>,
pub vcs_cvs: Option<String>,
pub vcs_arch: Option<String>,
pub vcs_mtn: Option<String>,
pub dgit: Option<DgitInfo>,
pub priority: Option<Priority>,
pub section: Option<String>,
pub format: Option<String>,
pub package_list: Vec<String>,
}Expand description
A source
Fields
directory: StringThe directory of the source
description: Option<String>Description of the source
version: VersionVersion of the source
package: StringPackage of the source
binaries: Option<Vec<String>>Binaries of the source
maintainer: Option<String>Maintainer of the source
build_depends: Option<Relations>Build dependencies of the source
build_depends_indep: Option<Relations>Build dependencies independent of the architecture of the source
build_depends_arch: Option<Relations>Build dependencies dependent on the architecture of the source
build_conflicts: Option<Relations>Build conflicts of the source
build_conflicts_indep: Option<Relations>Build conflicts independent of the architecture of the source
build_conflicts_arch: Option<Relations>Build conflicts dependent on the architecture of the source
standards_version: Option<String>Standards version of the source
homepage: Option<String>Homepage of the source
autobuild: Option<bool>Whether the source should be autobuilt
testsuite: Option<String>Testsuite of the source
testsuite_triggers: Option<Vec<String>>The packages triggering the testsuite of the source
vcs_browser: Option<String>VCS browser of the source
vcs_git: Option<String>VCS Git of the source
vcs_bzr: Option<String>VCS Bzr of the source
vcs_hg: Option<String>VCS Hg of the source
vcs_svn: Option<String>VCS SVN of the source
vcs_darcs: Option<String>VCS Darcs of the source
vcs_cvs: Option<String>VCS CVS of the source
vcs_arch: Option<String>VCS Arch of the source
vcs_mtn: Option<String>VCS Mtn of the source
dgit: Option<DgitInfo>Dgit information (commit, suite, ref, url)
priority: Option<Priority>Priority of the source
section: Option<String>Section of the source
format: Option<String>Format of the source
package_list: Vec<String>Package list of the source