pub struct Binary {Show 18 fields
pub name: String,
pub depends: Option<Relations>,
pub recommends: Option<Relations>,
pub suggests: Option<Relations>,
pub enhances: Option<Relations>,
pub pre_depends: Option<Relations>,
pub breaks: Option<Relations>,
pub conflicts: Option<Relations>,
pub replaces: Option<Relations>,
pub provides: Option<Relations>,
pub built_using: Option<Relations>,
pub static_built_using: Option<Relations>,
pub architecture: Option<String>,
pub section: Option<String>,
pub priority: Option<Priority>,
pub multi_arch: Option<MultiArch>,
pub essential: Option<bool>,
pub description: Option<String>,
}Expand description
A binary package.
Fields
name: StringThe name of the package.
depends: Option<Relations>The packages that this package depends on.
recommends: Option<Relations>The packages that this package recommends.
suggests: Option<Relations>The packages that this package suggests.
enhances: Option<Relations>The packages that this package enhances.
pre_depends: Option<Relations>The packages that this package depends on before it is installed.
breaks: Option<Relations>The packages that this package breaks.
conflicts: Option<Relations>The packages that this package conflicts with.
replaces: Option<Relations>The packages that this package replaces.
provides: Option<Relations>The packages that this package provides.
built_using: Option<Relations>The packages that this package is built using.
static_built_using: Option<Relations>The packages that this package is statically built using.
architecture: Option<String>The architecture the package is built for.
section: Option<String>The section of the package.
priority: Option<Priority>The priority of the package.
multi_arch: Option<MultiArch>The multi-arch field.
essential: Option<bool>Whether the package is essential.
description: Option<String>The description of the package. The first line is the short description, and the rest is the long description.