Relation

Struct Relation 

pub struct Relation {
    pub name: String,
    pub archqual: Option<String>,
    pub architectures: Option<Vec<String>>,
    pub version: Option<(VersionConstraint, Version)>,
    pub profiles: Vec<Vec<BuildProfile>>,
}
A relation entry in a relationship field.

Fields

name: String

Package name.

archqual: Option<String>

Architecture qualifier.

architectures: Option<Vec<String>>

Architectures that this relation is only valid for.

version: Option<(VersionConstraint, Version)>

Version constraint and version.

profiles: Vec<Vec<BuildProfile>>

Build profiles that this relation is only valid for.

Implementations

Source

impl Relation

pub fn new() -> Self

Create an empty relation.

pub fn build(name: &str) -> RelationBuilder

Build a new relation

pub fn satisfied_by(&self, package_version: impl VersionLookup) -> bool

Check if this entry is satisfied by the given package versions.

Arguments
  • package_version - A function that returns the version of a package.
Example
use debian_control::lossy::Relation;
let entry: Relation = "samba (>= 2.0)".parse().unwrap();
assert!(entry.satisfied_by(|name: &str| -> Option<debversion::Version> {
   match name {
   "samba" => Some("2.0".parse().unwrap()),
   _ => None
}}));